import { h, Component, Prop, State } from "@stencil/core";
import Clipboard from "clipboard";
import { css } from "emotion";
import { API } from "../../services/WidgetHost";
import { addClass, removeClass } from "../../utilities";
export class MiniCopyBox {
    componentWillLoad() {
        return API.graphql
            .getShareLink()
            .then(res => {
            this.sharelink = res;
        })
            .catch(e => {
            this.onError(e);
        });
    }
    onError(e) {
        console.log("Error loading via GraphQL.", e);
    }
    notify(clipboardNotification, notificationText) {
        const notification = document.getElementById(clipboardNotification.slice(1));
        notification.textContent = notificationText;
        addClass(notification, "in");
        setTimeout(() => {
            removeClass(notification, "in");
        }, 1400);
        API.analytics.shareEvent("DIRECT");
    }
    notifySuccess(e) {
        this.notify(e.trigger.dataset.clipboardNotification, this.copysuccess);
    }
    notifyFailure(e) {
        this.notify(e.trigger.dataset.clipboardNotification, this.copyfailure);
    }
    componentDidLoad() {
        const clipboard = new Clipboard("[data-clipboard-target]");
        clipboard.on("success", this.notifySuccess.bind(this));
        clipboard.on("error", this.notifyFailure.bind(this));
    }
    render() {
        const style = css `
      --border-rad: 8px;
      display: flex;
      flex-direction: column;
      width: 100%;
      max-width: 300px;
      padding: 12px 0;

      input {
        height: 72px;
        width: 100%;
        border: 1px solid #e2e8ec;
        border-radius: var(--border-rad);
        outline: none;
        padding: 0 20px 0 20px;
        overflow: scroll;

        color: #232323;
        text-overflow: ellipsis;
        font-size: 16px;

        &:hover {
          border: 1px solid gray;
        }

        @media screen and (max-width: 499px) {
          height: 59px;
        }
      }

      .input-group-btn > button {
        min-width: 170px;
        text-align: center;
        border-radius: 999px;
        margin-top: 16px;
        padding: 10px 0px;

        cursor: pointer;

        @media screen and (min-width: 500px) {
          width: 100%;
        }

        border: 2px solid ${this.buttoncolor};
        outline: none;
        -webkit-appearance: none;

        color: ${this.textcolor};
        background-color: ${this.buttoncolor};
        font-size: 16px;
      }
    `;
        return (!this.ishidden && (h("div", { class: `input-group ${style} ${this.class}` },
            h("input", { id: "squatch-share-link", value: this.sharelink, readonly: "readonly" }),
            h("span", { class: "input-group-btn" },
                h("button", { class: "sqh-copy-btn icon-btn", "data-clipboard-target": "#squatch-share-link", "data-clipboard-notification": "#squatch-share-notification" },
                    h("span", { class: "copied", id: "squatch-share-notification" }, this.text))))));
    }
    static get is() { return "mini-copy-box"; }
    static get originalStyleUrls() { return {
        "$": ["mini-copy-box.css"]
    }; }
    static get styleUrls() { return {
        "$": ["mini-copy-box.css"]
    }; }
    static get properties() { return {
        "ishidden": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "ishidden",
            "reflect": false
        },
        "text": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "text",
            "reflect": false
        },
        "copysuccess": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "copysuccess",
            "reflect": false
        },
        "copyfailure": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "copyfailure",
            "reflect": false
        },
        "buttoncolor": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "buttoncolor",
            "reflect": false
        },
        "textcolor": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "textcolor",
            "reflect": false
        },
        "class": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "class",
            "reflect": false
        }
    }; }
    static get states() { return {
        "copied": {},
        "sharelink": {}
    }; }
}
