import { h, Component, Prop, Element } from "@stencil/core";
import { shadeColor, detectMobileSafari, detectMobileChrome, } from "../../utilities";
import { css } from "emotion";
export class ShareButton {
    clickHandler(e) {
        if (window["widgetIdent"].env === "demo") {
            e.preventDefault();
            return;
        }
        // checking for null on closest 'a' tag makes click handler avoid firing when margin is clicked
        var anchor = e.target.closest("a");
        if (anchor !== null && this.buttonClassName !== "email-share") {
            e.preventDefault();
            const url = this.url;
            const target = "_blank";
            const features = "status=0,width=680,height=580";
            window.open(url, target, features);
        }
    }
    componentDidLoad() {
        let el = this.button;
        el.addEventListener("click", this.clickHandler.bind(this), false);
    }
    render() {
        const isMobileiOS = detectMobileSafari() || detectMobileChrome();
        const target = isMobileiOS ? "_parent" : "_blank";
        const iconClass = `icon icon-${this.icon}`;
        const style = css `
      background-color: ${this.backgroundcolor};
      border: 1px solid ${this.backgroundcolor};
      color: ${this.textcolor};

      &:hover {
        background: ${shadeColor(this.backgroundcolor, 10)};
        border-color: ${shadeColor(this.backgroundcolor, 12)};
        color: ${this.textcolor};
      }
      &:focus {
        color: ${this.textcolor};
      }
      .icon-${this.icon} {
        left: ${this.iconhorizontal}px;
        top: ${this.iconvertical}px;
        font-size: ${this.iconsize}em;
      }
    `;
        const classes = [
            `squatch-share-btn`,
            this.buttonClassName,
            this.displayrule,
            style,
        ].join(" ");
        return (h("a", { class: classes, href: this.url, target: target },
            h("i", { class: iconClass })));
    }
    static get is() { return "wa-share-button"; }
    static get originalStyleUrls() { return {
        "$": ["share-button.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["share-button.css"]
    }; }
    static get properties() { return {
        "displayrule": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "displayrule",
            "reflect": false
        },
        "text": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "text",
            "reflect": false
        },
        "backgroundcolor": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "backgroundcolor",
            "reflect": false
        },
        "textcolor": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "textcolor",
            "reflect": false
        },
        "icon": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "icon",
            "reflect": false
        },
        "buttonClassName": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "button-class-name",
            "reflect": false
        },
        "iconhorizontal": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "iconhorizontal",
            "reflect": false
        },
        "iconvertical": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "iconvertical",
            "reflect": false
        },
        "iconsize": {
            "type": "number",
            "mutable": false,
            "complexType": {
                "original": "number",
                "resolved": "number",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "iconsize",
            "reflect": false
        },
        "type": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "type",
            "reflect": false
        },
        "url": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "url",
            "reflect": false
        }
    }; }
    static get elementRef() { return "button"; }
}
