import { ApolloClient } from "apollo-client";
import { HttpLink } from "apollo-link-http";
import { InMemoryCache } from "apollo-cache-inmemory";
import gql from "graphql-tag";
if (!window["widgetIdent"]) {
    window["widgetIdent"] = {
        env: "demo"
    };
}
export function widgetIdent() {
    //@ts-ignore
    return window.widgetIdent;
}
const demoUser = {
    shareLink: "http://ssqt.co",
    messageLink: "http://example.com",
    fueltankCode: "12AS3F",
    referralcode: "RIDDIKULUS",
};
//@ts-ignore
const squatchJsApi = window.frameElement ? window.frameElement.squatchJsApi : {};
const apolloClient = () => {
    const { tenantAlias, appDomain, token } = widgetIdent();
    const uri = appDomain + "/api/v1/" + tenantAlias + "/graphql";
    const headers = {
        Authorization: `Bearer ${token}`
    };
    const client = new ApolloClient({
        link: new HttpLink({ uri, headers }),
        cache: new InMemoryCache()
    });
    return client;
};
const API = {
    version: "Welcome to widget-host",
    analytics: {
        shareEvent(shareMedium) {
            const widgetId = widgetIdent();
            if (widgetId["env"] === "demo" || !widgetId)
                return Promise.resolve({});
            const { userId, accountId, programId = "classic", engagementMedium, } = widgetId;
            const variables = {
                eventMeta: {
                    id: userId,
                    accountId,
                    programId,
                    type: "USER_REFERRAL_PROGRAM_ENGAGEMENT_EVENT",
                    meta: {
                        engagementMedium,
                        shareMedium,
                    },
                },
            };
            return apolloClient()
                .mutate({
                mutation: gql `
            mutation($eventMeta: UserAnalyticsEvent!) {
              createUserAnalyticsEvent(eventMeta: $eventMeta)
            }
          `,
                variables,
            })
                .then((result) => {
                return result.data.createUserAnalyticsEvent;
            });
        },
        loadEvent() {
            return Promise.resolve({ event: "loadEvent" });
        },
    },
    graphql: {
        getClient() {
            return apolloClient();
        },
        getUserFragment(userFragment, fragmentVariables) {
            const fragment = gql `
          fragment UserFragment on User {
            ${userFragment}
          }`;
            const { userId, accountId } = widgetIdent();
            const variables = {
                ...fragmentVariables,
                userId,
                accountId,
            };
            return this.getClient().query({
                query: gql `
          query($userId: String!, $accountId: String!, $offset: Int) {
            user(id: $userId, accountId: $accountId) {
              ...UserFragment
            }
          }
          ${fragment}
        `,
                variables,
            });
        },
        getShareLink() {
            const widgetId = widgetIdent();
            if (widgetId["env"] === "demo" || !widgetId)
                return Promise.resolve(demoUser.shareLink);
            const { userId, accountId, programId = null, engagementMedium, } = widgetId;
            const variables = {
                userId,
                accountId,
                programId,
                engagementMedium,
            };
            return this.getClient()
                .query({
                query: gql `
            query(
              $userId: String!
              $accountId: String!
              $programId: ID
              $engagementMedium: UserEngagementMedium!
            ) {
              user(id: $userId, accountId: $accountId) {
                shareLink(
                  programId: $programId
                  engagementMedium: $engagementMedium
                  shareMedium: DIRECT
                )
              }
            }
          `,
                variables,
            })
                .then((res) => res.data.user.shareLink);
        },
        getMessageLink(medium) {
            const widgetId = widgetIdent();
            const { userId, accountId, programId = null, engagementMedium, } = widgetId;
            const variables = {
                userId,
                accountId,
                programId,
                engagementMedium,
            };
            return this.getClient()
                .query({
                query: gql `
          query($userId: String!, $accountId: String!, $programId: ID, $engagementMedium: UserEngagementMedium!) {
            user(id: $userId, accountId: $accountId) {
              messageLink(programId: $programId, shareMedium: ${medium}, engagementMedium: $engagementMedium)
            }
          }
        `,
                variables,
            })
                .then((res) => res.data.user.messageLink);
        },
        getMessageLinks(mediums) {
            const widgetId = widgetIdent();
            if (widgetId["env"] === "demo" || !widgetId)
                return Promise.resolve(demoUser.messageLink);
            const { userId, accountId, programId = null, engagementMedium, } = widgetId;
            const variables = {
                userId,
                accountId,
                programId,
                engagementMedium,
            };
            return this.getClient()
                .query({
                query: gql `
          query($userId: String!, $accountId: String!, $programId: ID, $engagementMedium: UserEngagementMedium!) {
            user(id: $userId, accountId: $accountId) {
              ${mediums[0]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[0]})
              ${mediums[1]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[1]})
              ${mediums[2]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[2]})
              ${mediums[3]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[3]})
              ${mediums[4]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[4]})
              ${mediums[5]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[5]})
              ${mediums[6]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[6]})
              ${mediums[7]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[7]})
              ${mediums[8]}:messageLink(programId: $programId, engagementMedium: $engagementMedium, shareMedium: ${mediums[8]})
            }
          }
        `,
                variables,
            })
                .then((res) => res.data.user);
        },
    },
    ui: squatchJsApi,
};
export { API };
